@@ -160,7 +160,7 @@ class Event(models.Model):
         if clear_prefetch:
             self.occurrence_set._remove_prefetched_objects()
 
-        persisted_occurrences = self.occurrence_set.filter()
+        persisted_occurrences = self.occurrence_set.all()
         occ_replacer = OccurrenceReplacer(persisted_occurrences)
         occurrences = self._get_occurrence_list(start, end)
         final_occurrences = []
